

package com.upay.sdk.icc;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.icc.v_3.builder.ApiOrderBuilder;
import com.upay.sdk.icc.v_3.entity.BillInfo;
import com.upay.sdk.icc.v_3.entity.BrowserInfo;
import com.upay.sdk.icc.v_3.entity.ShipInfo;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.upay.sdk.icc.v_3.executer.ApiOrderExecuter;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 下单
* */
public class ApiOrderServlet extends HttpServlet {
    static final Logger LOGGER = LoggerFactory.getLogger(ApiOrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {


        String merchantId = req.getParameter("merchantId");
        String orderAmount = req.getParameter("orderAmount");
        String orderCurrency = req.getParameter("orderCurrency");
        String requestId = req.getParameter("requestId");
        String notifyUrl = req.getParameter("notifyUrl");
        String terminalNo = req.getParameter("terminalNo");
        String remark = req.getParameter("remark");
        String firstName = req.getParameter("firstName");
        String lastName = req.getParameter("lastName");
        String cardNo = req.getParameter("cardNo");
        String expireM = req.getParameter("expireM");
        String expireY = req.getParameter("expireY");
        String cardCvv2 = req.getParameter("cardCvv2");
        String ordip = req.getParameter("ordip");
        String callbackUrl = req.getParameter("callbackUrl");
        String projectId = req.getParameter("projectId");

        ApiOrderBuilder builder = new ApiOrderBuilder(merchantId);
        builder.setRequestId(requestId)
                .setOrderAmount(orderAmount)
                .setOrderCurrency(orderCurrency)
                .setNotifyUrl(notifyUrl)
                .setRemark(remark)
                .setOrdip(ordip)
                .setTerminalNo(terminalNo)
                .setFirstName(firstName)
                .setLastName(lastName)
                .setCardNo(cardNo)
                .setExpireM(expireM)
                .setExpireY(expireY)
                .setCardCvv2(cardCvv2)
                .setCallbackUrl(callbackUrl)
                .setProjectId(projectId);

        //送货信息
        String shipStreet = req.getParameter("shipStreet");
        String shipCity = req.getParameter("shipCity");
        String shipState = req.getParameter("shipState");
        String shipPost = req.getParameter("shipPost");
        String shipCountry = req.getParameter("shipCountry");
        String shipPhone = req.getParameter("shipPhone");
        String shipEmail = req.getParameter("shipEmail");

        //账单信息
        String billStreet = req.getParameter("billStreet");
        String billCity = req.getParameter("billCity");
        String billState = req.getParameter("billState");
        String billPost = req.getParameter("billPost");
        String billCountry = req.getParameter("billCountry");
        String billPhone = req.getParameter("billPhone");
        String billEmail = req.getParameter("billEmail");

        //浏览器信息
        String acceptHeader = req.getParameter("acceptHeader");
        String javaEnabled = req.getParameter("javaEnabled");
        String terminalType = req.getParameter("terminalType");
        String language = req.getParameter("language");
        String colorDepth = req.getParameter("colorDepth");
        String screenHeight = req.getParameter("screenHeight");
        String screenWidth = req.getParameter("screenWidth");
        String timeZoneoffset = req.getParameter("timeZoneoffset");
        String userAgent = req.getParameter("userAgent");


        ShipInfo shipInfo = new ShipInfo();
        shipInfo.setShipStreet(shipStreet);
        shipInfo.setShipCity(shipCity);
        shipInfo.setShipState(shipState);
        shipInfo.setShipPost(shipPost);
        shipInfo.setShipCountry(shipCountry);
        shipInfo.setShipPhone(shipPhone);
        shipInfo.setShipEmail(shipEmail);
        builder.setShipInfo(shipInfo);

        BillInfo billInfo = new BillInfo();
        billInfo.setBillStreet(billStreet);
        billInfo.setBillCity(billCity);
        billInfo.setBillState(billState);
        billInfo.setBillPost(billPost);
        billInfo.setBillCountry(billCountry);
        billInfo.setBillPhone(billPhone);
        billInfo.setBillEmail(billEmail);
        builder.setBillInfo(billInfo);

        BrowserInfo browserInfo = new BrowserInfo();
        browserInfo.setAcceptHeader(acceptHeader);
        browserInfo.setJavaEnabled(javaEnabled);
        browserInfo.setTerminalType(terminalType);
        browserInfo.setLanguage(language);
        browserInfo.setColorDepth(colorDepth);
        browserInfo.setScreenHeight(screenHeight);
        browserInfo.setScreenWidth(screenWidth);
        browserInfo.setTimeZoneoffset(timeZoneoffset);
        browserInfo.setUserAgent(userAgent);
        builder.setBrowserInfo(browserInfo);



        final PrintWriter out = resp.getWriter();
        LOGGER.info("请求数据:"+ ToStringBuilder.reflectionToString(builder));
        try {
            ApiOrderExecuter executer = new ApiOrderExecuter();
            executer.bothOrder(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功，不代表支付成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json", jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    resp.sendRedirect(redirectUrl);
                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}