

package com.upay.sdk.icc;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;

import com.upay.sdk.icc.v_3.builder.RefundQueryBuilder;

import com.upay.sdk.icc.v_3.executer.RefundQueryExecuter;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * 退款查询
 * */
public class RefundQueryServlet extends HttpServlet {
    static final Logger LOGGER = LoggerFactory.getLogger(RefundQueryServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {


        String merchantId = req.getParameter("merchantId");
        String requestId = req.getParameter("requestId");

        RefundQueryBuilder builder = new RefundQueryBuilder(merchantId)
                .setRequestId(requestId);

        final PrintWriter out = resp.getWriter();

        LOGGER.info("请求数据："+ ToStringBuilder.reflectionToString(builder));
        try{
            RefundQueryExecuter executer = new RefundQueryExecuter();
            executer.bothQuery(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功，不代表支付成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json",jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void failure(JSONObject jsonObject) {
                    LOGGER.debug("failure jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json",jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }
            });
        }
        catch(ResponseException e){
            out.println("响应异常</br>");
            out.println(e.toString());
        }
        catch(HmacVerifyException e){
            out.println("签名验证异常</br>");
            out.println(e.toString());
        }
        catch(RequestException e){
            out.println("请求异常</br>");
            out.println(e.toString());
        }
        catch(UnknownException e){
            out.println("未知异常</br>");
            out.println(e.toString());
        }

    }

}
